summaryrefslogtreecommitdiff
path: root/libavcodec/intrax8.h
diff options
context:
space:
mode:
Diffstat (limited to 'libavcodec/intrax8.h')
-rw-r--r--libavcodec/intrax8.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libavcodec/intrax8.h b/libavcodec/intrax8.h
index 3ebbf73434..966f1b18a0 100644
--- a/libavcodec/intrax8.h
+++ b/libavcodec/intrax8.h
@@ -27,9 +27,9 @@
#include "mpegpicture.h"
typedef struct IntraX8Context {
- VLC *j_ac_vlc[4]; // they point to the static j_mb_vlc
- VLC *j_orient_vlc;
- VLC *j_dc_vlc[3];
+ const VLCElem *j_ac_vlc_table[4]; // they point to the static j_mb_vlc.table
+ const VLCElem *j_orient_vlc_table;
+ const VLCElem *j_dc_vlc_table[3];
int use_quant_matrix;